@@ -29,7 +29,7 @@ def ValidatorMethod(requestClass=None, message=None, logMessage=None) :
                 FlaskManager.validateArgs(args,requestClass,innerResourceInstanceMethod)
                 methodReturn = resourceInstanceMethod(*args,**kwargs)
             except Exception as exception :
-                FlaskManager.raiseGlobalException(exception, resourceInstance, resourceInstanceMethod)
+                FlaskManager.raiseAndPersistGlobalException(exception, resourceInstance, resourceInstanceMethod)
             return methodReturn
         ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
         return innerResourceInstanceMethod
